"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generatePackageJson = void 0;
const fs = require("fs");
const path_1 = require("path");
const fileutils_1 = require("@nrwl/workspace/src/utils/fileutils");
const create_package_json_1 = require("@nrwl/workspace/src/utilities/create-package-json");
const config_1 = require("@nrwl/node/src/utils/config");
const generatePackageJson = (projectName, graph, options, outFile, workspaceRoot) => {
    const packageJson = create_package_json_1.createPackageJson(projectName, graph, options);
    packageJson.main = config_1.OUT_FILENAME;
    delete packageJson.devDependencies;
    const dependencies = {};
    const buildFile = fs.readFileSync(outFile, 'utf8');
    const re2 = /"(.*)"/gm;
    const externalDependencies = buildFile.match(/require\("(.*)"\)/gm);
    // Get the package version from the root
    if (externalDependencies) {
        const workspacePackages = fileutils_1.readJsonFile(path_1.join(workspaceRoot, 'package.json'));
        const dependenciesName = externalDependencies.map((x) => x.match(re2)[0].replace(/"/gm, ''));
        dependenciesName.forEach((dep) => {
            let depName = dep;
            let packageIsDefined = depName in workspacePackages.dependencies;
            if (!packageIsDefined) {
                if (depName.includes('/')) {
                    depName = depName.split('/').shift();
                    packageIsDefined = depName in workspacePackages.dependencies;
                }
            }
            if (packageIsDefined) {
                dependencies[depName] = workspacePackages.dependencies[depName];
            }
            else {
                console.warn(`Could not add "${dep}", is it added to the package.json?`);
            }
        });
    }
    const projectPackageJson = path_1.join(options.projectRoot, 'package.json');
    const originalPackageJson = fileutils_1.fileExists(projectPackageJson)
        ? fileutils_1.readJsonFile(projectPackageJson)
        : { dependencies: {} };
    packageJson.dependencies = Object.assign(Object.assign({}, originalPackageJson.dependencies), dependencies);
    fileutils_1.writeJsonFile(`${options.outputPath}/package.json`, packageJson);
};
exports.generatePackageJson = generatePackageJson;
//# sourceMappingURL=generate-package-json.js.map